using DailyWork;
using Microsoft.EntityFrameworkCore;

var builder = WebApplication.CreateBuilder(args);

builder.Services.AddDbContext<WorkDb>(opt => opt.UseInMemoryDatabase("WorkDatabase"));

var app = builder.Build();

app.MapGet("/", () => "Welcome to Minimal API Project");

app.MapPost("/works", async (Work work, WorkDb db) =>
{
	db.Works.Add(work);
	await db.SaveChangesAsync();

	return Results.Created($"/works/{work.Id}", work);
});

app.MapGet("/works", async (WorkDb db) =>
	await db.Works.ToListAsync());

app.MapGet("/works/complete", async (WorkDb db) =>
	await db.Works.Where(t => t.IsComplete).ToListAsync());

app.MapGet("/works/{id}", async (int id, WorkDb db) =>
	await db.Works.FindAsync(id)
		is Work work
			? Results.Ok(work)
			: Results.NotFound());

app.MapPut("/works/{id}", async (int id, Work work, WorkDb db) =>
{
	var todo = await db.Works.FindAsync(id);

	if (todo is null) return Results.NotFound();

	todo.Name = work.Name;
	todo.IsComplete = work.IsComplete;

	await db.SaveChangesAsync();

	return Results.NoContent();
});

app.MapDelete("/works/{id}", async (int id, WorkDb db) =>
{
	if (await db.Works.FindAsync(id) is Work work)
	{
		db.Works.Remove(work);
		await db.SaveChangesAsync();
		return Results.NoContent();
	}

	return Results.NotFound();
});

app.Run();
